@@ -4,7 +4,6 @@ from .tools import *
 class AZlyrics(Requester):
     """
     Fast and Secure API for AZLyrics.com
-
     Attributes:
         title (str): song title
         artist (str): singer name
@@ -78,8 +77,15 @@ class AZlyrics(Requester):
 
         page = self.get(link, self.proxies)
         if page.status_code != 200:
-            print('Error 404!')
-            return 1
+            if not self.search_engine:
+                print('Failed to find lyrics. Trying to get link from Google')
+                self.search_engine = 'google'
+                lyrics = self.getLyrics(url=url, ext=ext, save=save, path=path, sleep=sleep)
+                self.search_engine = ''
+                return lyrics
+            else:
+                print('Error',page.status_code)
+                return 1
 
         # Getting Basic metadata from azlyrics
         metadata = [elm.text for elm in htmlFindAll(page)('b')]
@@ -117,7 +123,6 @@ class AZlyrics(Requester):
     def getSongs(self, sleep=3):
         """
         Reterive a dictionary of songs with their links
-
         Parameters:
             sleep (float): cooldown before next request.  
         
@@ -151,8 +156,15 @@ class AZlyrics(Requester):
         
         albums_page = self.get(link, self.proxies)
         if albums_page.status_code != 200:
-            print('Error 404!')
-            return {}
+            if not self.search_engine:
+                print('Failed to find songs. Trying to get link from Google')
+                self.search_engine = 'google'
+                songs = self.getLyrics(sleep=sleep)
+                self.search_engine = ''
+                return songs
+            else:
+                print('Error',albums_page.status_code)
+                return {}
         
         # Store songs for later usage
         self.songs = parseSongs(albums_page)
